Coverage for modules/box__default/base/view.py: 86%

# Coverage for modules/box__default/base/view.py : 86%

## 7 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 from shopyo.api.module import ModuleHelp

2

3# from flask import render_template

4# from flask import url_for

5# from flask import redirect

6# from flask import flash

7# from flask import request

8

9# from shopyo.api.html import notify_success

10# from shopyo.api.forms import flash_errors

11

12 mhelp = ModuleHelp(__file__, __name__)

13 globals()[mhelp.blueprint_str] = mhelp.blueprint

14 module_blueprint = globals()[mhelp.blueprint_str]

15

16

17@module_blueprint.route("/")

18 def index():

19 return mhelp.info["display_string"]

20

21

22# If "dashboard": "/dashboard" is set in info.json

23#

24# @module_blueprint.route("/dashboard", methods=["GET"])

25# def dashboard():

26

27# context = mhelp.context()

28

29# context.update({

30

31# })

32# return mhelp.render('dashboard.html', **context)